@@ -2,6 +2,7 @@
 
 #include "catch.hpp"
 #include "global.h"
+#include <random>
 
 double ANCHOR_P_VALUE = 0.025;
 int FLAGS = flags::none;
@@ -9,3 +10,4 @@ int THREADS = 1;
 long unsigned int BOOTSTRAP = 0;
 int RETURN_CODE = EXIT_SUCCESS;
 size_t reference_index = 0;
+std::mt19937 prng;
